@@ -2,7 +2,7 @@
  *
  * rdf_init.c - Redland library initialisation / termination
  *
- * Copyright (C) 2000-2010, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2000-2011, David Beckett http://www.dajobe.org/
  * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
@@ -37,7 +37,7 @@
 #include <pthread.h>
 #endif
 #ifdef HAVE_STDLIB_H
-#include <stdlib.h> /* for abort() as used in errors */
+#include <stdlib.h>
 #endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h> /* for getpid() */
@@ -68,9 +68,9 @@
 
 #ifndef STANDALONE
 
-const char * const librdf_short_copyright_string = "Copyright 2000-2010 David Beckett. Copyright 2000-2005 University of Bristol";
+const char * const librdf_short_copyright_string = "Copyright 2000-2011 David Beckett. Copyright 2000-2005 University of Bristol";
 
-const char * const librdf_copyright_string = "Copyright (C) 2000-2010 David Beckett - http://www.dajobe.org/\nCopyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/";
+const char * const librdf_copyright_string = "Copyright (C) 2000-2011 David Beckett - http://www.dajobe.org/\nCopyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/";
 
 /**
  * librdf_version_string:
@@ -195,12 +195,13 @@ librdf_free_world(librdf_world *world)
   librdf_finish_node(world);
   librdf_finish_uri(world);
 
+  /* Uses rdf_hash so free before destroying hashes */
+  librdf_finish_raptor(world);
+
   librdf_finish_hash(world);
 
   librdf_finish_digest(world);
 
-  librdf_finish_raptor(world);
-
 #ifdef WITH_THREADS
 
   if(world->hash_datums_mutex) {
@@ -275,20 +276,22 @@ librdf_world_init_mutex(librdf_world* world)
 void
 librdf_world_open(librdf_world *world)
 {
+  int rc = 0;
+  
   if(world->opened++)
     return;
   
   librdf_world_init_mutex(world);
 
-  /* Initialize raptor library first. Used by many other classes. */
-  librdf_init_raptor(world);
-  
   /* Digests second, lots of things use these */
   librdf_init_digest(world);
 
   /* Hash next, needed for URIs */
   librdf_init_hash(world);
 
+  /* Initialize raptor; uses rdf_hash for bnode mapping */
+  librdf_init_raptor(world);
+  
   librdf_init_uri(world);
   librdf_init_node(world);
 
@@ -301,7 +304,15 @@ librdf_world_open(librdf_world *world)
   librdf_init_parser(world);
   librdf_init_serializer(world);
 
-  librdf_init_query(world);
+  rc = librdf_init_query(world);
+  if(rc)
+    goto failed;
+  
+  return;
+  
+failed:
+  /* should return an error state */
+  return;
 }
 
 
@@ -475,7 +486,7 @@ librdf_world_set_feature(librdf_world* world, librdf_uri* feature,
 #ifdef WITH_THREADS
       pthread_mutex_lock(world->mutex);
 #endif
-      world->genid_base = 1;
+      world->genid_base = i;
 #ifdef WITH_THREADS
       pthread_mutex_unlock(world->mutex);
 #endif
@@ -492,7 +503,7 @@ librdf_world_set_feature(librdf_world* world, librdf_uri* feature,
 #ifdef WITH_THREADS
       pthread_mutex_lock(world->mutex);
 #endif
-      world->genid_counter = 1;
+      world->genid_counter = i;
 #ifdef WITH_THREADS
       pthread_mutex_unlock(world->mutex);
 #endif
@@ -788,7 +799,7 @@ main(int argc, char *argv[])
 
   fprintf(stdout, "%s: Generating an identifier\n", program);
   id = librdf_world_get_genid(world);
-  if(id == NULL || strlen(id) < 6) {
+  if(id == NULL || strlen((const char*)id) < 6) {
     fprintf(stderr, "%s: librdf_world_get_genid failed\n", program);
     return 1;
   }
